(define-package "magit-forge" "0.3.2"
  "Access Git forges from Magit."
  '((emacs          "25.1")
    (closql         "1.2.0")
    (dash           "2.19.1")
    (emacsql-sqlite "3.0.0")
    (ghub           "3.5.4")
    (let-alist      "1.0.6")
    (magit          "3.3.0")
    (markdown-mode  "2.4")
    (transient      "0.3.6")
    (yaml           "0.3.4"))
  :homepage "https://github.com/magit/forge"
  :keywords '("git" "tools" "vc"))
